package com.dragon.tj.portal.auth.module.zerotrust;

import com.dragon.tj.portal.auth.model.LoginUser;
import com.dragon.tj.portal.auth.service.MyUserDetailsService;
import org.jasig.cas.client.validation.AssertionImpl;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.security.authentication.AuthenticationProvider;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.cas.authentication.CasAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.core.userdetails.UserDetails;

public class ZeroTrustAuthenticationProvider implements AuthenticationProvider {
    private static final Logger LOGGER = LoggerFactory.getLogger(ZeroTrustAuthenticationProvider.class);
    private final MyUserDetailsService userDetailsService;

    public ZeroTrustAuthenticationProvider(MyUserDetailsService userDetailsService) {
        this.userDetailsService = userDetailsService;
    }

    @Override
    public Authentication authenticate(Authentication authentication) throws AuthenticationException {
        if (authentication.getPrincipal() == null || "".equals(authentication.getPrincipal())) {
            throw new BadCredentialsException("Failed to get the user token");
        }
        if (authentication.getCredentials() == null || "".equals(authentication.getCredentials())) {
            throw new BadCredentialsException("Failed to get the app token");
        }
        String userToken = authentication.getName();
        String appToken = authentication.getCredentials().toString();
        LOGGER.info("Current User Token: {}, App Token: {}", userToken, appToken);
        UserDetails userDetails = userDetailsService.loadUserByZeroTrust(userToken, appToken);
        if (userDetails instanceof LoginUser) {
            ((LoginUser) userDetails).setUserToken(userToken);
            ((LoginUser) userDetails).setAppToken(appToken);
        }
        return new CasAuthenticationToken("ZeroTrust", userDetails, authentication.getCredentials(),
                userDetails.getAuthorities(), userDetails, new AssertionImpl(""));
    }

    @Override
    public boolean supports(Class<?> authentication) {
        return UsernamePasswordAuthenticationToken.class.isAssignableFrom(authentication);
    }
}
