package com.dragon.tj.portal.auth.service;

import cn.hutool.json.JSONUtil;
import com.dragon.tj.portal.auth.model.LoginUser;
import org.springframework.http.MediaType;
import org.springframework.security.core.Authentication;
import org.springframework.security.web.authentication.logout.LogoutSuccessHandler;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

public class JwtTokenLogoutSuccessHandler implements LogoutSuccessHandler {

    private final String homeUrl;
    private final String logoutUrl;
    private final TokenService tokenService;

    public JwtTokenLogoutSuccessHandler(String homeUrl, String logoutUrl, TokenService tokenService) {
        this.homeUrl = homeUrl;
        this.logoutUrl = logoutUrl;
        this.tokenService = tokenService;
    }

    /**
     * 退出处理
     */
    @Override
    public void onLogoutSuccess(HttpServletRequest request, HttpServletResponse response, Authentication authentication)
            throws IOException, ServletException {
        LoginUser loginUser = tokenService.getLoginUser(request);
        if (Objects.nonNull(loginUser)) {
            // 删除redis记录
            tokenService.delLoginUser(loginUser.getToken());
        }
        Map<String, String> data = new HashMap<>();
        data.put("casLogoutUrl", logoutUrl + "?service=" + URLEncoder.encode(homeUrl, StandardCharsets.UTF_8.name()));
        response.setStatus(HttpServletResponse.SC_OK);
        response.setContentType(MediaType.APPLICATION_JSON_VALUE);
        response.getWriter().write(JSONUtil.toJsonStr(data));
    }
}
