package com.dragon.tj.portal.auth.service;

import com.dragon.tj.portal.auth.model.LoginUser;
import com.dragon.tj.portal.auth.web.entity.SysUser;
import com.dragon.tj.portal.auth.web.service.SysUserService;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;

import java.util.HashSet;
import java.util.List;
import java.util.Objects;

/**
 * 用户验证处理
 *
 * @author tienchin
 */
@Service
public class MyUserDetailsService implements UserDetailsService {
    private final SysUserService userService;
    private final SysPermissionService sysPermissionService;

    public MyUserDetailsService(SysUserService userService, SysPermissionService sysPermissionService) {
        this.userService = userService;
        this.sysPermissionService = sysPermissionService;
    }

    @Override
    public UserDetails loadUserByUsername(String key) throws UsernameNotFoundException {
        SysUser user = userService.getUserByKey(key);
        if (Objects.isNull(user)) {
            throw new UsernameNotFoundException(key);
        }
        return createLoginUser(user);
    }

    private UserDetails createLoginUser(SysUser sysUser) {
        List<String> permissions = sysPermissionService.getMenuPermission(sysUser);
        return new LoginUser(sysUser.getIdcard(), sysUser.getOrgCode(), sysUser, new HashSet<>(permissions));
    }

    public UserDetails loadUserByZeroTrust(String userToken, String appToken) {
        SysUser user = userService.getUserFromZeroTrust(userToken);
        if (Objects.isNull(user)) {
            throw new UsernameNotFoundException(userToken);
        }
        return createLoginUserByZeroTrust(user, userToken, appToken);
    }

    private UserDetails createLoginUserByZeroTrust(SysUser sysUser, String userToken, String appToken) {
        List<String> permissions = sysPermissionService.getMenuPermissionFromZeroTrust(userToken, appToken);
        return new LoginUser(sysUser.getIdcard(), sysUser.getOrgCode(), sysUser, new HashSet<>(permissions));
    }
}
