package com.dragon.tj.portal.auth.web.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.OrderItem;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.dragon.tj.portal.auth.model.RR;
import com.dragon.tj.portal.auth.model.zeroTrust.AuthenticationResponse;
import com.dragon.tj.portal.auth.model.zeroTrust.AuthenticationResult;
import com.dragon.tj.portal.auth.module.cas.CasAuthenticationClient;
import com.dragon.tj.portal.auth.module.zerotrust.ZeroTrustAuthenticationClient;
import com.dragon.tj.portal.auth.properties.CasProperties;
import com.dragon.tj.portal.auth.properties.ZeroTrustProperties;
import com.dragon.tj.portal.auth.web.entity.SysUser;
import com.dragon.tj.portal.auth.web.mapper.SysUserMapper;
import com.dragon.tj.portal.auth.web.service.SysUserService;
import com.dragon.tj.portal.entity.PageParam;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import retrofit2.Call;

import java.util.Objects;

/**
 * <p>
 * 用户信息表 服务实现类
 * </p>
 *
 * @author caiaa
 * @since 2023-06-23
 */
@Service
public class SysUserServiceImpl extends ServiceImpl<SysUserMapper, SysUser> implements SysUserService {
    private static final Logger LOGGER = LoggerFactory.getLogger(SysUserServiceImpl.class);

    private final CasProperties casProperties;
    private final ZeroTrustProperties zeroTrustProperties;
    private final CasAuthenticationClient casAuthenticationClient;
    private final ZeroTrustAuthenticationClient zeroTrustAuthenticationClient;

    public SysUserServiceImpl(
            CasProperties casProperties, ZeroTrustProperties zeroTrustProperties,
            CasAuthenticationClient casAuthenticationClient,
            ZeroTrustAuthenticationClient zeroTrustAuthenticationClient) {
        this.casProperties = casProperties;
        this.zeroTrustProperties = zeroTrustProperties;
        this.casAuthenticationClient = casAuthenticationClient;
        this.zeroTrustAuthenticationClient = zeroTrustAuthenticationClient;
    }

    @Override
    public SysUser getUserByKey(String key) {
        return getUserFromDcuc(key);
    }

    @Override
    public Page<SysUser> list(PageParam<SysUser> pageParam) {
        Page<SysUser> page = new Page<>(pageParam.getPage(), pageParam.getSize());
        String order = pageParam.getOrder();
        if (StringUtils.isNotBlank(order)) {
            page.addOrder(OrderItem.asc(order));
        }

        SysUser sysUser = pageParam.getParams();
        LambdaQueryWrapper<SysUser> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.like(StringUtils.isNotEmpty(sysUser.getName()), SysUser::getName, sysUser.getName());
        queryWrapper.like(StringUtils.isNotEmpty(sysUser.getPoliceNumber()), SysUser::getPoliceNumber, sysUser.getPoliceNumber());
        queryWrapper.eq(StringUtils.isNotBlank(sysUser.getOrgCode()), SysUser::getOrgCode, sysUser.getOrgCode());
        queryWrapper.in(!CollectionUtils.isEmpty(sysUser.getOrgCodes()), SysUser::getOrgCode, sysUser.getOrgCodes());
        queryWrapper.eq(SysUser::getDeleted, "0");
        return baseMapper.selectPage(page, queryWrapper);
    }

    public SysUser getUserFromDcuc(String idCard) {
        SysUser sysUser = null;
        try {
            LOGGER.info("登录用户[{}]调用DCUC用户管理服务-获取警员详情接口", idCard);
            Call<RR<SysUser>> call = casAuthenticationClient.getUserInfo(casProperties.getAppCode(), idCard, idCard);
            RR<SysUser> body = call.execute().body();
            if (Objects.nonNull(body)) {
                if ("200".equals(body.getStatusCode())) {
                    sysUser = body.getResult();
                    LOGGER.info("登录用户[{}]调用DCUC用户管理服务-获取警员详情接口 成功: {}", idCard, sysUser);
                } else {
                    LOGGER.error("登录用户[{}]调用DCUC用户管理服务-获取警员详情接口 出错: {}", idCard, body.getMessage());
                }
            } else {
                LOGGER.error("登录用户[{}]调用DCUC用户管理服务-获取警员详情接口 出错: 返回为空", idCard);
            }
        } catch (Exception e) {
            LOGGER.error("登录用户[{}]调用DCUC用户管理服务-获取警员详情接口 出错", idCard, e);
        }
        return sysUser;
    }

    @Override
    public SysUser getUserFromZeroTrust(String userToken) {
        SysUser sysUser = null;
        try {
            LOGGER.info("登录用户[{}]调用零信任-获取认证用户接口", userToken);
            Call<AuthenticationResponse> call = zeroTrustAuthenticationClient.getUserInfo(
                    zeroTrustProperties.getAppCode(), userToken);
            AuthenticationResponse body = call.execute().body();
            if (Objects.nonNull(body)) {
                if (AuthenticationResponse.SUCCESS.equals(body.getTag())) {
                    AuthenticationResult result = body.getResult();
                    sysUser = new SysUser();
                    sysUser.setIdcard(result.getSfzh());
                    sysUser.setName(result.getXm());
                    sysUser.setPoliceNumber(result.getJh());
                    sysUser.setOrgCode(result.getDwdm());
                    sysUser.setOrgName(result.getDwmc());
                    LOGGER.info("登录用户[{}]调用零信任-获取认证用户接口 成功: {}", userToken, sysUser);
                } else {
                    LOGGER.error("登录用户[{}]调用零信任-获取认证用户接口 出错: {}", userToken, body.getMsg().getInfo());
                }
            } else {
                LOGGER.error("登录用户[{}]调用零信任-获取认证用户接口 出错: 返回为空", userToken);
            }
        } catch (Exception e) {
            LOGGER.error("登录用户[{}]调用零信任-获取认证用户接口 出错", userToken, e);
        }
        return sysUser;
    }

}
