/*
 *
 *      Copyright (c) 2018-2025, frame All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the pig4cloud.com developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: frame
 *
 */

package com.dragon.tj.portal.component.log.uitl;

import cn.hutool.core.util.URLUtil;
import cn.hutool.extra.servlet.ServletUtil;
import cn.hutool.http.HttpUtil;
import com.dragon.tj.portal.auth.util.SecurityUtils;
import com.dragon.tj.portal.component.log.dto.SysLogDTO;
import lombok.experimental.UtilityClass;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import java.util.Objects;

/**
 * @author huey China.
 * @Description : 系统日志工具类
 * @Date Created in 2023/6/12 16:17
 */
@Slf4j
@UtilityClass
public class SysLogUtils {

    public SysLogDTO getSysLog() {
        HttpServletRequest request = ((ServletRequestAttributes) Objects
                .requireNonNull(RequestContextHolder.getRequestAttributes())).getRequest();
        SysLogDTO sysLog = new SysLogDTO();
        sysLog.setCreateBy(Objects.requireNonNull(getUsername()));

        sysLog.setCreateOrgCode(Objects.requireNonNull(SecurityUtils.getLoginUser().getUser().getOrgCode()));
        sysLog.setCreateOrgName(Objects.requireNonNull(SecurityUtils.getLoginUser().getUser().getOrgName()));
        sysLog.setSysNumber(getSysCode(request));

        sysLog.setType(LogTypeEnum.NORMAL.getType());
        sysLog.setRemoteAddr(ServletUtil.getClientIP(request));
        sysLog.setRequestUri(URLUtil.getPath(request.getRequestURI()));
        sysLog.setMethod(request.getMethod());
        sysLog.setUserAgent(request.getHeader("user-agent"));
        sysLog.setParams(HttpUtil.toParams(request.getParameterMap()));
        return sysLog;
    }

    public SysLogDTO getSysLog(HttpServletRequest request, String username) {
        SysLogDTO sysLog = new SysLogDTO();
        sysLog.setCreateBy(username);
        sysLog.setType(LogTypeEnum.NORMAL.getType());
        sysLog.setRemoteAddr(ServletUtil.getClientIP(request));
        sysLog.setRequestUri(URLUtil.getPath(request.getRequestURI()));
        sysLog.setMethod(request.getMethod());
        sysLog.setUserAgent(request.getHeader("user-agent"));
        sysLog.setParams(HttpUtil.toParams(request.getParameterMap()));
        return sysLog;
    }

    /**
     * 获取用户名称
     *
     * @return username
     */
    private String getUsername() {
        return SecurityUtils.getLoginUser().getUsername();
    }

    private final String sysCode = "sys-number";

    private static String getSysCode(HttpServletRequest request) {
        // 1. 取出请求里面的所有头信息  ---- 得到一个枚举集合
        String sysCodeRst = request.getHeader(sysCode);
        return StringUtils.isNotEmpty(sysCodeRst) ? sysCodeRst : StringUtils.EMPTY;
    }

}
