package com.dragon.tj.portal.component.message;

import com.dragon.tj.portal.service.MessageInfoService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.servlet.mvc.method.annotation.SseEmitter;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.Map;

/**
 * @author huey China.
 * @Description : 控制
 * @Date Created in 2023/6/15 15:43
 */
@Slf4j
@RestController
public class SseController {

    @Resource
    private Map<String, OpenApiSseEmitter> sseEmitters;

    @Autowired
    private MessageInfoService messageInfoService;

    @GetMapping("/subscribe/{clientId}")
    public SseEmitter subscribe(@PathVariable String clientId, HttpServletResponse response) {

        response.addHeader("Cache-Control", "no-cache");
        response.addHeader("X-Accel-Buffering", "no");
        response.setHeader("Access-Control-Allow-Origin", "*");

        log.info("got a subscription, clientId={} will be bound to serverId={}", clientId, "appId");
        // 创建一个新的SseEmitter对象并设置超时时间，并将其存储在Map中
        OpenApiSseEmitter emitter = new OpenApiSseEmitter(Long.MAX_VALUE);
        sseEmitters.put(clientId, emitter);
        emitter.onCompletion(() -> sseEmitters.remove(clientId));

        return emitter;
    }

}
