package com.dragon.tj.portal.controller;

import com.dragon.tj.portal.auth.model.LoginUser;
import com.dragon.tj.portal.auth.util.SecurityUtils;
import com.dragon.tj.portal.common.base.R;
import com.dragon.tj.portal.common.enums.log.ModuleEnum;
import com.dragon.tj.portal.component.log.annotation.SysLog;
import com.dragon.tj.portal.entity.BusinessInfo;
import com.dragon.tj.portal.entity.InstallInfo;
import com.dragon.tj.portal.entity.PageParam;
import com.dragon.tj.portal.service.BusinessService;
import com.dragon.tj.portal.service.InstallInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/business")
public class BusinessController {

    @Autowired
    private BusinessService businessService;

    @Autowired
    private InstallInfoService installInfoService;

    /*
     *    1. 我的业务查询 批量排序收藏
     * */
    @SysLog(value = "收藏业务查询", module = ModuleEnum.BUSINESS_QUERY)
    @PostMapping("list")
    public R appList(@RequestBody PageParam<BusinessInfo> businessPage) {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        return R.ok(businessService.installApp(businessPage, loginUser));
    }

    /*
     *  1-1安装业务
     * */
    @SysLog(value = "收藏业务", module = ModuleEnum.BUSINESS_COLLECTION)
    @GetMapping("install/{appId}/{businessId}")
    public R install(@PathVariable("appId") Integer appId,
                     @PathVariable("businessId") Integer businessId) {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        int install = businessService.install(appId, businessId, loginUser.getIdCard());

        if (install == 0) {

            return R.failed("安装失败!!!");
        }
        return R.ok();
    }

    /*
     *  1-2卸载业务
     * */
    @SysLog(value = "取消收藏业务", module = ModuleEnum.BUSINESS_COLLECTION)
    @GetMapping("uninstall/{appId}/{businessId}")
    public R uninstall(@PathVariable("appId") Integer appId,
                       @PathVariable("businessId") Integer businessId) {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        return R.ok(businessService.uninstall(appId, businessId, loginUser.getIdCard()));
    }

    /***************************************/

    /*
     *    2. 类型查询
     * */
//    @GetMapping("types")
//    public R getAppType() {
//        return businessService.getType();
//    }

    /*
     *    3. 应用 CRUD
     * */
    @SysLog(value = "添加业务", module = ModuleEnum.BUSINESS_ADD)
    @PostMapping("add")
    public R addApp(@RequestBody BusinessInfo businessInfo) {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        int b = businessService.add(businessInfo, loginUser);
        if (b == 0) {
            return R.failed("添加失败!!!");
        }

        return R.ok(b);
    }

    @SysLog(value = "批量添加业务", module = ModuleEnum.BUSINESS_ADD)
    @PostMapping("batchAdd")
    public R batchAdd(MultipartFile file) {
        boolean result = businessService.batchAdd(file);
        return result ? R.ok() : R.failed();
    }

    //    @SysLog("删除业务")
    @SysLog(value = "删除业务", module = ModuleEnum.BUSINESS_DELETE)
    @GetMapping("delete/{id}")
    public R delete(@PathVariable("id") Long id) {
        return R.ok(businessService.delete(id));
    }

    //    @SysLog("更新业务")
    @SysLog(value = "更新业务", module = ModuleEnum.BUSINESS_UPDATE)
    @PostMapping("update")
    public R update(@RequestBody BusinessInfo businessInfo) {
        businessInfo.setUpdateTime(LocalDateTime.now());
        return R.ok(businessService.update(businessInfo));
    }

    /*
     *   批量更新收藏
     * */
    @SysLog(value = "批量更新收藏业务", module = ModuleEnum.BUSINESS_UPDATE)
    @PostMapping("batchUpdate")
    public R batchUpdate(@RequestBody List<InstallInfo> list) {
        installInfoService.batchUpdate(list, 1);
        return R.ok();
    }

    @SysLog(value = "通过ID获取业务", module = ModuleEnum.BUSINESS_QUERY)
    @GetMapping("info/{id}")
    public R detail(@PathVariable("id") Long id) {
        return R.ok(businessService.detail(id));
    }

    /*
     *   通过应用名称,应用事权单位名称搜索app
     * */
    @SysLog(value = "通过应用名称,应用事权单位名称搜索app", module = ModuleEnum.BUSINESS_QUERY)
    @PostMapping("search")
    public R search(@RequestBody PageParam<BusinessInfo> businessInfoPage) {

        return R.ok(businessService.search(businessInfoPage));
    }

    /*
     *   点击量
     * */
    @PostMapping("clickIncr")
    @SysLog(value = "业务点击", module = ModuleEnum.BUSINESS_CLICK)
    public R clickIncr(@RequestBody Map<String, Object> params) {
        Object id = params.get("id");

        return id == null ? R.failed("业务Id不能为空")
                : R.ok(businessService.clickIncr(Long.valueOf(id.toString())));
    }

    /*
     *    4. 热门应用统计 定时、实时？
     * */
    // @Scheduled(fixedDelay = 1000 * 60 * 60)
    public void appStatHandler() {

        businessService.updateAppStat();
    }

}

