package com.dragon.tj.portal.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.dragon.tj.portal.auth.model.LoginUser;
import com.dragon.tj.portal.auth.util.SecurityUtils;
import com.dragon.tj.portal.common.base.R;
import com.dragon.tj.portal.common.enums.log.ModuleEnum;
import com.dragon.tj.portal.component.log.annotation.SysLog;
import com.dragon.tj.portal.entity.CommentDetailInfo;
import com.dragon.tj.portal.entity.CommentInfo;
import com.dragon.tj.portal.entity.PageParam;
import com.dragon.tj.portal.service.CommentService;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 在线留言
 */
@RestController
@RequestMapping("/comment")
public class CommentController {

    private final CommentService commentService;

    public CommentController(CommentService commentService) {
        this.commentService = commentService;
    }

    /*
     *   CRUD
     * */
    @SysLog(value = "提交留言", module = ModuleEnum.COMMENT_ADD)
    @PostMapping("add")
    public R<Integer> add(@RequestBody CommentInfo commentInfo) {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        int b = commentService.add(commentInfo, loginUser);
        if (b == 0) {
            return R.failed("添加失败!!!");
        }

        return R.ok(b);
    }

    /*
     *   通过标题,内容搜索
     * */
    @SysLog(value = "通过内容搜索", module = ModuleEnum.COMMENT_QUERY)
    @PostMapping("search")
    public R<Page<CommentInfo>> search(@RequestBody PageParam<CommentInfo> pageParam) {
        return R.ok(commentService.search(pageParam));
    }

    /**
     * 详情查询
     */
    @SysLog(value = "详情搜索", module = ModuleEnum.COMMENT_DETAIL_QUERY)
    @PostMapping("detail/search")
    public R<Page<CommentDetailInfo>> detailSearch(@RequestBody PageParam<CommentDetailInfo> pageParam) {
        return R.ok(commentService.detailSearch(pageParam));
    }

    /**
     * 详情新增
     */
    @SysLog(value = "详情添加", module = ModuleEnum.COMMENT_ADD)
    @PostMapping("detail/add")
    public R<Integer> detailAdd(@RequestBody CommentDetailInfo detailInfo) {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        int b = commentService.detailAdd(detailInfo, loginUser);
        if (b == 0) {
            return R.failed("添加失败!!!");
        }
        return R.ok(b);
    }

}
