package com.dragon.tj.portal.controller;

import com.dragon.tj.portal.common.base.R;
import com.dragon.tj.portal.common.enums.log.ModuleEnum;
import com.dragon.tj.portal.component.log.annotation.SysLog;
import com.dragon.tj.portal.entity.ExternalApp;
import com.dragon.tj.portal.entity.PageParam;
import com.dragon.tj.portal.service.ExternalAppService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping("/external")
public class ExternalAppController {

    @Autowired
    private ExternalAppService externalAppService;

    /*
     *    外部应用 CRUD
     * */
    @SysLog(value = "外部应用添加", module = ModuleEnum.APP_ADD)
    @PostMapping("add")
    public R addApp(@RequestBody ExternalApp appInfo) {
        return R.ok(externalAppService.add(appInfo));
    }

    @SysLog(value = "外部应用删除", module = ModuleEnum.APP_DELETE)
    @GetMapping("delete/{id}")
    public R delete(@PathVariable("id") Long id) {
        return R.ok(externalAppService.delete(id));
    }

    @SysLog(value = "外部应用更新", module = ModuleEnum.APP_UPDATE)
    @PostMapping("update")
    public R update(@RequestBody ExternalApp appInfo) {
        return R.ok(externalAppService.update(appInfo));
    }

    @SysLog(value = "通过ID获取外部应用", module = ModuleEnum.APP_QUERY)
    @GetMapping("info/{id}")
    public R detail(@PathVariable("id") Long id) {
        return R.ok(externalAppService.detail(id));
    }

    /*
     *  搜索
     * */
    @SysLog(value = "搜索外部应用", module = ModuleEnum.APP_QUERY)
    @PostMapping("search")
    public R search(@RequestBody PageParam<ExternalApp> appInfoPage) {

        return R.ok(externalAppService.search(appInfoPage));
    }

}

