package com.dragon.tj.portal.controller;

import com.dragon.tj.portal.common.base.R;
import com.dragon.tj.portal.common.enums.log.ModuleEnum;
import com.dragon.tj.portal.component.log.annotation.SysLog;
import com.dragon.tj.portal.entity.FileInfo;
import com.dragon.tj.portal.entity.PageParam;
import com.dragon.tj.portal.service.FileManageService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.InputStreamResource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.io.InputStream;

@RestController
@RequestMapping("/fileMge")
public class FileManageController {

    @Autowired
    private FileManageService fileManageService;

    /*
     * 文件上传
     * */
    @SysLog(value = "文件上传", module = ModuleEnum.FILE_UPLOAD)
    @PostMapping("/upload/{type}")
    public R upload(MultipartFile file, @PathVariable("type") Integer type) {

        return R.ok().setData(fileManageService.upload(file, type));
    }

    /*
     *   文件软件搜索
     * */
    @SysLog(value = "文件软件搜索", module = ModuleEnum.FILE_QUERY)
    @PostMapping("search")
    public R search(@RequestBody PageParam<FileInfo> appInfoPage) {

        return R.ok(fileManageService.search(appInfoPage));
    }

    /*
     *   获取Top 数量
     * */
    @SysLog(value = "获取Top 数量", module = ModuleEnum.FILE_QUERY)
    @GetMapping("top/{type}/{num}")
    public R search(@PathVariable("type") String type, @PathVariable("num") Integer num) {
        return R.ok(fileManageService.top(type, num));
    }

    /*
     *  模板文件下载
     * */
    @SysLog(value = "模板文件下载", module = ModuleEnum.FILE_QUERY)
    @GetMapping("temp/{type}")
    public ResponseEntity<InputStreamResource> downloadTemp(@PathVariable("type") String type) throws IOException {
//        String path = AppService.class.getClassLoader().getResource("").getPath();
//        path = URLDecoder.decode(path, "UTF-8");

//        String filePath = path + "file/" + type + ".xlsx";
        String filename = type + ".xlsx";
        ClassPathResource classPathResource = new ClassPathResource("file/" + filename);
        InputStream inputStream = classPathResource.getInputStream();
//        FileSystemResource file = new FileSystemResource(filePath);
        HttpHeaders headers = new HttpHeaders();
        headers.add("Cache-Control", "no-cache, no-store, must-revalidate");
        headers.add("Content-Disposition", String.format("attachment; filename=\"%s\"", filename));
        headers.add("Pragma", "no-cache");
        headers.add("Expires", "0");
        return ResponseEntity
                .ok()
                .headers(headers)
//                .contentLength(file.contentLength())
                .contentType(MediaType.parseMediaType("application/octet-stream"))
                .body(new InputStreamResource(inputStream));
    }

    /*
     * 软件删除
     * */
    @SysLog(value = "软件删除", module = ModuleEnum.FILE_DELETE)
    @GetMapping("/delete/{id}")
    public R delete(@PathVariable("id") Integer id) {

        return R.ok(fileManageService.delete(id));
    }
}
