package com.dragon.tj.portal.controller;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.dragon.tj.portal.auth.model.LoginUser;
import com.dragon.tj.portal.auth.util.SecurityUtils;
import com.dragon.tj.portal.common.base.R;
import com.dragon.tj.portal.common.dto.message.MessageInfoReq;
import com.dragon.tj.portal.common.enums.log.ModuleEnum;
import com.dragon.tj.portal.common.vo.message.ContactMemberVO;
import com.dragon.tj.portal.common.vo.message.MessageInfoParam;
import com.dragon.tj.portal.common.vo.message.MessageInfoVO;
import com.dragon.tj.portal.common.vo.message.MessagePageParam;
import com.dragon.tj.portal.component.log.annotation.SysLog;
import com.dragon.tj.portal.service.MessageInfoService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * <p>
 * 信息表 前端控制器
 * </p>
 *
 * @author huey
 * @since 2023-06-15
 */
@Slf4j
@RestController
@RequestMapping("/messageInfo")
public class MessageInfoController {

    @Autowired
    private MessageInfoService messageInfoService;

    @PostMapping("/publish")
    public R publish(@Validated @RequestBody MessageInfoReq messageInfoReq) {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        log.info("api/message/publish-req-is {}-{}", JSON.toJSONString(loginUser), JSON.toJSONString(messageInfoReq));
        return messageInfoService.push(messageInfoReq, loginUser);
    }

    /**
     * 分页查询
     *
     * @param page
     * @param req
     * @return
     */
    @GetMapping("/page")
    public R page(Page page, MessagePageParam req) {
        IPage iPage = messageInfoService.queryPage(page, req);
        return R.ok(iPage);
    }

    /**
     * 详情
     */
    @GetMapping("detail")
    public R detail(Long id) {
        MessageInfoVO messageInfoVO = messageInfoService.detail(id);
        return R.ok(messageInfoVO);
    }

    /**
     * 修改
     */
    @SysLog(value = "信息更新", module = ModuleEnum.NOTICE_UPDATE)
    @PostMapping("update")
    public R update(@Validated @RequestBody MessageInfoParam messageInfoParam) {
        return R.ok(messageInfoService.update(messageInfoParam));
    }

    /**
     * 阅读
     */
    @GetMapping("read")
    public R read(Long id) {
        return R.ok(messageInfoService.read(id));
    }

    /**
     * 批阅
     */
    @GetMapping("reads")
    public R reads(@RequestParam List<Long> ids) {
        return R.ok(messageInfoService.reads(ids));
    }

    @GetMapping("contacts")
    public R getContactsMemberList(@RequestParam(value = "limit", defaultValue = "10") Integer limit) {
        List<ContactMemberVO> list = messageInfoService.getContactsMemberList(limit);
        return R.ok(list);
    }

    @GetMapping("/getCount")
    public R getCount() {
        return R.ok(messageInfoService.getCount());
    }
}

