package com.dragon.tj.portal.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.dragon.tj.portal.common.base.R;
import com.dragon.tj.portal.common.enums.log.ModuleEnum;
import com.dragon.tj.portal.common.vo.message.MessagePageParam;
import com.dragon.tj.portal.common.vo.notice.NoticeInfoParam;
import com.dragon.tj.portal.common.vo.notice.NoticeInfoVO;
import com.dragon.tj.portal.component.log.annotation.SysLog;
import com.dragon.tj.portal.service.NoticeInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * <p>
 * 消息 前端控制器
 * </p>
 *
 * @author huey
 * @since 2023-06-15
 */
@RestController
@RequestMapping("/noticeInfo")
public class NoticeInfoController {

    @Autowired
    private NoticeInfoService noticeInfoService;

    /**
     * 分页查询
     *
     * @param page
     * @param req
     * @return
     */
    @GetMapping("/page")
    public R page(Page page, MessagePageParam req) {
        IPage iPage = noticeInfoService.queryPage(page, req);
        return R.ok(iPage);
    }

    /**
     * 详情
     */
    @GetMapping("detail")
    public R detail(Long id) {
        NoticeInfoVO messageInfoVO = noticeInfoService.detail(id);
        return R.ok(messageInfoVO);
    }

    /**
     * 修改
     */
    @SysLog(value = "消息更新", module = ModuleEnum.NOTICE_UPDATE)
    @PostMapping("update")
    public R update(@Validated @RequestBody NoticeInfoParam messageInfoParam) {
        return R.ok(noticeInfoService.update(messageInfoParam));
    }

    /**
     * 阅读 targetId
     */
    @GetMapping("read")
    public R read(Long id) {
        return R.ok(noticeInfoService.read(id));
    }

    /**
     * 批阅 targetId
     */
    @GetMapping("reads")
    public R reads(List<Long> ids) {
        return R.ok(noticeInfoService.reads(ids));
    }
}

