package com.dragon.tj.portal.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.metadata.OrderItem;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.dc.eventpoi.ExcelHelper;
import com.dragon.tj.portal.auth.model.LoginUser;
import com.dragon.tj.portal.auth.util.SecurityUtils;
import com.dragon.tj.portal.common.base.R;
import com.dragon.tj.portal.entity.AppInfo;
import com.dragon.tj.portal.entity.BusinessInfo;
import com.dragon.tj.portal.entity.InstallInfo;
import com.dragon.tj.portal.entity.PageParam;
import com.dragon.tj.portal.entity.SysDictItem;
import com.dragon.tj.portal.mapper.BusinessMapper;
import com.dragon.tj.portal.mapper.app.AppInfoMapper;
import com.dragon.tj.portal.mapper.app.InstallInfoMapper;
import com.dragon.tj.portal.service.BusinessService;
import com.dragon.tj.portal.service.SysDictItemService;
import com.dragon.tj.portal.service.SysDictService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.ClassPathResource;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
public class BusinessServiceImpl implements BusinessService {
    private static final Logger LOGGER = LoggerFactory.getLogger(BusinessServiceImpl.class);

    @Autowired
    private BusinessMapper businessMapper;

    @Autowired
    private AppInfoMapper appInfoMapper;

    @Autowired
    private InstallInfoMapper installInfoMapper;

    @Autowired
    private SysDictService sysDictService;

    @Autowired
    private SysDictItemService sysDictItemService;

    private static List<SysDictItem> businessTypeDict;

    /*
     * CRUD
     * */
    @Override
    public int add(BusinessInfo businessInfo, LoginUser loginUser) {
        businessInfo.setCreateUser(loginUser.getUsername());
        // 获取应用
        QueryWrapper<AppInfo> wrapper = new QueryWrapper<>();
        wrapper.eq(businessInfo.getAppId() != null,
                "id", businessInfo.getAppId());
        wrapper.like(businessInfo.getAppName() != null,
                "system_name", businessInfo.getAppName());

        List<AppInfo> appInfoList = appInfoMapper.selectList(wrapper);

        if (appInfoList == null || appInfoList.size() > 1) {

            return 0;
        }

        businessInfo.setAppId(appInfoList.get(0).getId());
        businessInfo.setAppName(appInfoList.get(0).getSystemName());

        return businessMapper.insert(businessInfo);
    }

    @Override
    public int delete(Long id) {
        BusinessInfo businessInfo = new BusinessInfo();
        businessInfo.setId(id);
        businessInfo.setDelFlag(1);

        return businessMapper.updateById(businessInfo);
    }

    @Override
    public int update(BusinessInfo businessInfo) {
        return businessMapper.updateById(businessInfo);
    }

    @Override
    public BusinessInfo detail(Long id) {
        return businessMapper.selectById(id);
    }

    /*
     * 获取类型
     * */
    @Override
    public R getType() {
        return R.ok(sysDictService.getDict("app_type"));
    }

    /*
     * 搜索App业务程序
     * */
    @Override
    public Page<BusinessInfo> search(PageParam<BusinessInfo> businessInfoPage) {

        BusinessInfo businessInfo = businessInfoPage.getParams();
        Page<BusinessInfo> rowPage = new Page(businessInfoPage.getPage(), businessInfoPage.getSize());

        LambdaQueryWrapper<BusinessInfo> queryWrapper = new LambdaQueryWrapper<>();

        // 应用名称
        queryWrapper.like(StringUtils.isNotEmpty(businessInfo.getAppName()),
                BusinessInfo::getAppName, businessInfo.getAppName());

        // 业务名称
        queryWrapper.like(StringUtils.isNotEmpty(businessInfo.getBusinessName()),
                BusinessInfo::getBusinessName, businessInfo.getBusinessName());

        // 类型
        queryWrapper.eq(businessInfo.getBusinessType() != null,
                BusinessInfo::getBusinessType,
                businessInfo.getBusinessType());
        queryWrapper.eq(businessInfo.getDelFlag() != null,
                BusinessInfo::getDelFlag,
                businessInfo.getDelFlag());

        rowPage.addOrder(OrderItem.desc(businessInfoPage.getOrder()));

        if (businessInfo.getIsStar() != null && businessInfo.getIsStar() == 1) {
            Page<BusinessInfo> businessInfoPage1 = businessMapper.selectPage(rowPage, queryWrapper);

            return checkFavorites(businessInfoPage1);
        }

        return businessMapper.selectPage(rowPage, queryWrapper);
    }

    /*
     * 热门应用是否收藏
     * */
    private Page<BusinessInfo> checkFavorites(Page<BusinessInfo> businessInfoPage) {
        List<BusinessInfo> records = businessInfoPage.getRecords();
        List<Long> ids = records.stream().map(BusinessInfo::getId).collect(Collectors.toList());
        if (ids.size() == 0) {
            return businessInfoPage;
        }
        LambdaQueryWrapper<InstallInfo> wrapper = new LambdaQueryWrapper<>();
        wrapper.select(InstallInfo::getBusinessId);
        wrapper.ne(InstallInfo::getBusinessId, 0);
        wrapper.eq(SecurityUtils.getLoginUser() != null,
                InstallInfo::getUserIdcard, SecurityUtils.getLoginUser().getIdCard());
        wrapper.in(InstallInfo::getBusinessId, ids);
        List<InstallInfo> installInfos = installInfoMapper.selectList(wrapper);

        Map<Integer, List<InstallInfo>> collect = installInfos.stream()
                .collect(Collectors.groupingBy(InstallInfo::getBusinessId));

        for (BusinessInfo info : records) {
            info.setIsStar(collect.get(info.getId().intValue()) != null ? 1 : 0);
        }

        return businessInfoPage;
    }

    /*
     * 安装业务
     * */
    @Override
    public int install(Integer appId, Integer businessId, String userIdcard) {

        // 查询业务是否存在
        QueryWrapper<BusinessInfo> wrapper = new QueryWrapper<>();
        wrapper.eq("app_id", appId);
        wrapper.eq("id", businessId);
        wrapper.eq("del_flag", 0);
        List<BusinessInfo> businessInfos = businessMapper.selectList(wrapper);

        if (businessInfos == null || businessInfos.size() != 1) {

            return 0;
        }

        // 是否已安装
        QueryWrapper<InstallInfo> wrapper2 = new QueryWrapper<>();
        wrapper2.eq("del_flag", 0);
        wrapper2.eq("app_id", appId);
        wrapper2.eq("business_id", businessId);
        wrapper2.eq("user_idcard", userIdcard);
        InstallInfo installed = installInfoMapper.selectOne(wrapper2);

        if (installed == null) {
            InstallInfo installInfo = new InstallInfo();
            installInfo.setAppId(appId);
            installInfo.setBusinessId(businessId);
            installInfo.setUserIdcard(userIdcard);

            return installInfoMapper.insert(installInfo);
        }

        installed.setDelFlag(0);
        installed.setUpdateTime(LocalDateTime.now());

        return installInfoMapper.updateById(installed);
    }

    /*
     * 卸载
     * */
    @Override
    public int uninstall(Integer appId, Integer businessId, String idCard) {
        InstallInfo installInfo = new InstallInfo();
        installInfo.setDelFlag(1);
        installInfo.setUpdateTime(LocalDateTime.now());
        QueryWrapper<InstallInfo> wrapper = new QueryWrapper<>();
        wrapper.eq("app_id", appId);
        wrapper.eq("business_id", businessId);
        wrapper.eq("user_idcard", idCard);

        return installInfoMapper.update(installInfo, wrapper);
    }

    /*
     *  已安装业务
     * */
    @Override
    public IPage<BusinessInfo> installApp(PageParam<BusinessInfo> page, LoginUser loginUser) {
        BusinessInfo params = page.getParams();
        IPage<BusinessInfo> iPage = new Page<>(page.getPage(), page.getSize());

        Map map = new HashMap();

        map.put("delFlag", params.getDelFlag());
        map.put("businessType", params.getBusinessType());
        map.put("idcard", loginUser.getIdCard());

        return businessMapper.getInstalledApp(iPage, map);

    }

    /*
     *  应用业务统计
     * */
    @Override
    public void updateAppStat() {
        // 获取app安装次数
        List<Map<String, Long>> business = installInfoMapper.getBusinessInstallCount();
        // 更新star
        business.forEach(bus -> {
            BusinessInfo businessInfo = new BusinessInfo();
            businessInfo.setId(bus.get("businessId"));
            businessInfo.setStar(bus.get("count"));
            businessMapper.updateById(businessInfo);
        });

    }

    @Override
    public int clickIncr(Long id) {
        QueryWrapper<BusinessInfo> wrapper = new QueryWrapper<>();
        wrapper.eq("id", id);
        BusinessInfo businessInfo = businessMapper.selectOne(wrapper);
        businessInfo.setId(id);
        businessInfo.setHits(businessInfo.getHits() + 1);

        return businessMapper.updateById(businessInfo);
    }

    @Override
    public boolean batchAdd(MultipartFile file) {
        InputStream inputStream = null;
        try {
            inputStream = file.getInputStream();
//            String path = AppService.class.getClassLoader().getResource("").getPath();
//            path = URLDecoder.decode(path, "UTF-8");
//            FileInputStream tempFis = new FileInputStream(new File(path + "file/businessTemplete.xlsx"));
            ClassPathResource classPathResource = new ClassPathResource("file/businessTemplete.xlsx");
            InputStream tempFis = classPathResource.getInputStream();

            List<BusinessInfo> businessInfos = ExcelHelper.parseExcelToObject(
                    new BufferedInputStream(tempFis),
                    inputStream,
                    BusinessInfo.class, true);

            businessInfos.forEach(businessInfo -> {
                BusinessInfo businessInfo1 = parseBusinessInfo(businessInfo);
                this.add(businessInfo1, SecurityUtils.getLoginUser());
            });

        } catch (Exception e) {
            LOGGER.error("上传出错", e);
            return false;
        } finally {
            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }

        return true;
    }

    private BusinessInfo parseBusinessInfo(BusinessInfo businessInfo) {
        List<SysDictItem> businessTypeDict = getBusinessTypeDict();

        // 类型表码转换
        String appTypeName = businessInfo.getTypeName();
        SysDictItem sysDictItem = businessTypeDict.stream()
                .filter(t -> t.getLabel().equals(appTypeName))
                .findFirst().get();
        businessInfo.setBusinessType(sysDictItem.getId());

        // 获取Appinfo
        QueryWrapper<AppInfo> wrapper = new QueryWrapper<>();
        wrapper.eq(businessInfo.getAppName() != null,
                "system_name", businessInfo.getAppName());

        AppInfo appInfo = appInfoMapper.selectOne(wrapper);
        businessInfo.setAppId(appInfo.getId());

        return businessInfo;

    }

    public List<SysDictItem> getBusinessTypeDict() {
        if (businessTypeDict == null || businessTypeDict.size() == 0) {
            businessTypeDict = sysDictItemService.list(Wrappers.<SysDictItem>query().lambda().eq(SysDictItem::getType, "business_type").orderByAsc(SysDictItem::getSort));
        }

        return businessTypeDict;
    }

}
