package com.dragon.tj.portal.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.dragon.tj.portal.common.base.R;
import com.dragon.tj.portal.common.constants.CacheConstants;
import com.dragon.tj.portal.entity.SysDict;
import com.dragon.tj.portal.entity.SysDictItem;
import com.dragon.tj.portal.mapper.SysDictItemMapper;
import com.dragon.tj.portal.mapper.SysDictMapper;
import com.dragon.tj.portal.service.SysDictService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cache.annotation.CacheEvict;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 字典表 服务实现类
 * </p>
 *
 * @author huey
 * @since 2023-06-12
 */
@Service
public class SysDictServiceImpl extends ServiceImpl<SysDictMapper, SysDict> implements SysDictService {

    @Autowired
    private SysDictItemMapper dictItemMapper;

    @Autowired
    private SysDictMapper dictMapper;

    /**
     * 根据ID 删除字典
     *
     * @param id 字典ID
     * @return
     */
    @CacheEvict(value = CacheConstants.DICT_DETAILS, allEntries = true)
    @Override
    @Transactional(rollbackFor = Exception.class)
    public R removeDict(Integer id) {
        SysDict dict = this.getById(id);
        // 系统内置

        baseMapper.deleteById(id);
        dictItemMapper.delete(Wrappers.<SysDictItem>lambdaQuery().eq(SysDictItem::getDictId, id));
        return R.ok();
    }

    /**
     * 更新字典
     *
     * @param dict 字典
     * @return
     */
    @CacheEvict(value = CacheConstants.DICT_DETAILS, allEntries = true)
    @Override
    public R updateDict(SysDict dict) {
        SysDict sysDict = this.getById(dict.getId());

        return R.ok(this.updateById(dict));
    }

    /**
     * 获取字典
     *
     * @param type 字典类型
     * @return
     */
    @Override
    public List<SysDict> getDict(String type) {
        QueryWrapper<SysDict> wrapper = new QueryWrapper();
        wrapper.eq("type", type);
        wrapper.eq("del_flag", 0);
        List<SysDict> sysDicts = dictMapper.selectList(wrapper);

        return sysDicts;
    }
}
